@@ -1,7 +1,7 @@
 from databasetools.csv import CSVExport, CSVImport, CSV
 from databasetools.sqlite import SQLiteSyntax, SQLiteQuery, SQLiteTools
 from databasetools.dict import DictTools
-from databasetools.mysql import MySQLTools
+from databasetools.sql import MySQLTools
 from databasetools.php import PHPArray
 from databasetools.json import JSON
 from databasetools.pickle import Pickle
